contentpublishingsrv/contentpublishingserver/cpserver/inc/cpserveractionmanager.h
branchRCL_3
changeset 12 502e5d91ad42
parent 0 79c6a41cd166
--- a/contentpublishingsrv/contentpublishingserver/cpserver/inc/cpserveractionmanager.h	Fri Mar 12 15:43:54 2010 +0200
+++ b/contentpublishingsrv/contentpublishingserver/cpserver/inc/cpserveractionmanager.h	Mon Mar 15 12:41:53 2010 +0200
@@ -26,7 +26,7 @@
 #endif
 class CLiwServiceHandler;
 class MLiwInterface;
-class CLiwDefaultMap;
+class CLiwMap;
 
 /**
  *  Used to execute action using Action Handler Service
@@ -88,10 +88,10 @@
     /**
      * Extracts and adds attributes from aMap to aTarget.
      * @since Series 60 3.2
      * @param aMap CLiwDefaultMap with action.
      * @param aTarget CLiwGenericParamList with Uid and Map.
      */
-    void ExtractUidAndMapL( const CLiwDefaultMap& aMap,
+    void ExtractUidAndMapL( const CLiwMap& aMap,
         CLiwGenericParamList& aTarget );
 
 private:
@@ -88,10 +88,10 @@
      * Extracts and adds attributes from aMap to aTarget.
      * @since Series 60 3.2
-     * @param aMap CLiwDefaultMap with action.
+     * @param aMap CLiwMap with action.
      * @param aTarget CLiwGenericParamList with Uid and Map.
      */